Title: [204444] trunk/Tools
Revision
204444
Author
gyuyoung....@webkit.org
Date
2016-08-12 23:11:49 -0700 (Fri, 12 Aug 2016)

Log Message

Skip to check directories existence in build-webkit
https://bugs.webkit.org/show_bug.cgi?id=160691

Reviewed by Alex Christensen.

CMake checks if directories are there itself. So CMake ports
don't need to check it in the build-webkit script.

* Scripts/build-webkit:
* Scripts/webkitdirs.pm:
(determineSourceDir):
(isCMakeBuild):

Modified Paths

Diff

Modified: trunk/Tools/ChangeLog (204443 => 204444)


--- trunk/Tools/ChangeLog	2016-08-13 05:05:10 UTC (rev 204443)
+++ trunk/Tools/ChangeLog	2016-08-13 06:11:49 UTC (rev 204444)
@@ -1,3 +1,18 @@
+2016-08-12  Gyuyoung Kim  <gyuyoung....@webkit.org>
+
+        Skip to check directories existence in build-webkit
+        https://bugs.webkit.org/show_bug.cgi?id=160691
+
+        Reviewed by Alex Christensen.
+
+        CMake checks if directories are there itself. So CMake ports
+        don't need to check it in the build-webkit script.
+
+        * Scripts/build-webkit:
+        * Scripts/webkitdirs.pm:
+        (determineSourceDir):
+        (isCMakeBuild):
+
 2016-08-12  Alex Christensen  <achristen...@webkit.org>
 
         Make URLParser work with URLs missing URL parts

Modified: trunk/Tools/Scripts/build-webkit (204443 => 204444)


--- trunk/Tools/Scripts/build-webkit	2016-08-13 05:05:10 UTC (rev 204443)
+++ trunk/Tools/Scripts/build-webkit	2016-08-13 06:11:49 UTC (rev 204444)
@@ -146,13 +146,16 @@
 my @projects = ("Source/_javascript_Core", "Source/WebCore", "Source/WebKit");
 
 # Build WTF as a separate static library on ports which support it.
-splice @projects, 0, 0, "Source/WTF" if isAppleMacWebKit() or isAppleWinWebKit() or isWinCairo();
+splice @projects, 0, 0, "Source/WTF" if isAppleWebKit() or isWinCairo();
 
 splice @projects, 0, 0, "Source/bmalloc" if isAppleMacWebKit();
 
-for my $dir (@projects) {
-    if (! -d $dir) {
-        die "Error: No $dir directory found. Please do a fresh checkout.\n";
+# Ports using CMake will check if directories exist in the CMake configuration.
+if (!isCMakeBuild()) {
+    for my $dir (@projects) {
+        if (! -d $dir) {
+            die "Error: No $dir directory found. Please do a fresh checkout.\n";
+        }
     }
 }
 

Modified: trunk/Tools/Scripts/webkitdirs.pm (204443 => 204444)


--- trunk/Tools/Scripts/webkitdirs.pm	2016-08-13 05:05:10 UTC (rev 204443)
+++ trunk/Tools/Scripts/webkitdirs.pm	2016-08-13 06:11:49 UTC (rev 204444)
@@ -167,8 +167,8 @@
     $sourceDir =~ s|/+$||; # Remove trailing '/' as we would die later
 
     # walks up path checking each directory to see if it is the main WebKit project dir, 
-    # defined by containing Sources, WebCore, and WebKit
-    until ((-d File::Spec->catdir($sourceDir, "Source") && -d File::Spec->catdir($sourceDir, "Source", "WebCore") && -d File::Spec->catdir($sourceDir, "Source", "WebKit")) || (-d File::Spec->catdir($sourceDir, "Internal") && -d File::Spec->catdir($sourceDir, "OpenSource")))
+    # defined by containing Sources, WebCore, and _javascript_Core.
+    until ((-d File::Spec->catdir($sourceDir, "Source") && -d File::Spec->catdir($sourceDir, "Source", "WebCore") && -d File::Spec->catdir($sourceDir, "Source", "_javascript_Core")) || (-d File::Spec->catdir($sourceDir, "Internal") && -d File::Spec->catdir($sourceDir, "OpenSource")))
     {
         if ($sourceDir !~ s|/[^/]+$||) {
             die "Could not find top level webkit directory above source directory using FindBin.\n";
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to